package com.ruoyi.project.production.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.production.mapper.TAlarmstatisticsDayMapper;
import com.ruoyi.project.production.domain.TAlarmstatisticsDay;
import com.ruoyi.project.production.service.ITAlarmstatisticsDayService;

import javax.annotation.Resource;

/**
 * 报警统计（当天）Service业务层处理
 *
 * @author ruoyi
 * @date 2020-11-26
 */
@Service
public class TAlarmstatisticsDayServiceImpl implements ITAlarmstatisticsDayService
{
    @Resource
    private TAlarmstatisticsDayMapper tAlarmstatisticsDayMapper;

    /**
     * 查询报警统计（当天）
     *
     * @param id 报警统计（当天）ID
     * @return 报警统计（当天）
     */
    @Override
    public TAlarmstatisticsDay selectTAlarmstatisticsDayById(Long id)
    {
        return tAlarmstatisticsDayMapper.selectTAlarmstatisticsDayById(id);
    }

    /**
     * 查询报警统计（当天）列表
     *
     * @param tAlarmstatisticsDay 报警统计（当天）
     * @return 报警统计（当天）
     */
    @Override
    public List<TAlarmstatisticsDay> selectTAlarmstatisticsDayList(TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        return tAlarmstatisticsDayMapper.selectTAlarmstatisticsDayList(tAlarmstatisticsDay);
    }

    /**
     * 新增报警统计（当天）
     *
     * @param tAlarmstatisticsDay 报警统计（当天）
     * @return 结果
     */
    @Override
    public int insertTAlarmstatisticsDay(TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        return tAlarmstatisticsDayMapper.insertTAlarmstatisticsDay(tAlarmstatisticsDay);
    }

    /**
     * 修改报警统计（当天）
     *
     * @param tAlarmstatisticsDay 报警统计（当天）
     * @return 结果
     */
    @Override
    public int updateTAlarmstatisticsDay(TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        return tAlarmstatisticsDayMapper.updateTAlarmstatisticsDay(tAlarmstatisticsDay);
    }

    /**
     * 批量删除报警统计（当天）
     *
     * @param ids 需要删除的报警统计（当天）ID
     * @return 结果
     */
    @Override
    public int deleteTAlarmstatisticsDayByIds(Long[] ids)
    {
        return tAlarmstatisticsDayMapper.deleteTAlarmstatisticsDayByIds(ids);
    }

    /**
     * 删除报警统计（当天）信息
     *
     * @param id 报警统计（当天）ID
     * @return 结果
     */
    @Override
    public int deleteTAlarmstatisticsDayById(Long id)
    {
        return tAlarmstatisticsDayMapper.deleteTAlarmstatisticsDayById(id);
    }
}