package com.ruoyi.project.production.controller;

import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import com.alibaba.fastjson.JSON;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.file.ExcelUtils;
import com.ruoyi.project.system.domain.SysDept;
import com.ruoyi.project.system.domain.SysDictData;
import com.ruoyi.project.system.service.ISysDeptService;
import com.ruoyi.project.system.service.ISysDictTypeService;
import org.apache.poi.ss.usermodel.*;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.production.domain.TAlarmstatisticsDay;
import com.ruoyi.project.production.service.ITAlarmstatisticsDayService;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 报警统计（昨天）Controller
 *
 * @author ruoyi
 * @date 2020-11-26
 */
@RestController
@RequestMapping("/production/day")
public class TAlarmstatisticsDayController extends BaseController
{
    @Autowired
    private ITAlarmstatisticsDayService tAlarmstatisticsDayService;

    @Autowired
    private ISysDictTypeService iSysDictTypeService;

    @Autowired
    private ISysDeptService iSysDeptService;

    /**
     * 查询报警统计（昨天）列表
     */
    @PreAuthorize("@ss.hasPermi('production:day:list')")
    @GetMapping("/list")
    public TableDataInfo list(TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        startPage();
        List<TAlarmstatisticsDay> list = tAlarmstatisticsDayService.selectTAlarmstatisticsDayList(tAlarmstatisticsDay);
        return getDataTable(list);
    }

    /**
     * 导出报警统计（昨天）列表
     */
    @PreAuthorize("@ss.hasPermi('production:day:export')")
    @Log(title = "报警统计（昨天）", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        List<TAlarmstatisticsDay> list = tAlarmstatisticsDayService.selectTAlarmstatisticsDayList(tAlarmstatisticsDay);
        ExcelUtil<TAlarmstatisticsDay> util = new ExcelUtil<TAlarmstatisticsDay>(TAlarmstatisticsDay.class);
        return util.exportExcel(list, "day");
    }

    /**
     * 获取报警统计（昨天）详细信息
     */
    @PreAuthorize("@ss.hasPermi('production:day:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tAlarmstatisticsDayService.selectTAlarmstatisticsDayById(id));
    }

    /**
     * 新增报警统计（昨天）
     */
    @PreAuthorize("@ss.hasPermi('production:day:add')")
    @Log(title = "报警统计（昨天）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        tAlarmstatisticsDay.setCreaterCode(getUserId().toString());
        return toAjax(tAlarmstatisticsDayService.insertTAlarmstatisticsDay(tAlarmstatisticsDay));
    }

    /**
     * 修改报警统计（昨天）
     */
    @PreAuthorize("@ss.hasPermi('production:day:edit')")
    @Log(title = "报警统计（昨天）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TAlarmstatisticsDay tAlarmstatisticsDay)
    {
        tAlarmstatisticsDay.setUpdaterCode(getUserId().toString());
        tAlarmstatisticsDay.setUpdatedate(new Date());
        return toAjax(tAlarmstatisticsDayService.updateTAlarmstatisticsDay(tAlarmstatisticsDay));
    }

    /**
     * 删除报警统计（昨天）
     */
    @PreAuthorize("@ss.hasPermi('production:day:remove')")
    @Log(title = "报警统计（昨天）", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tAlarmstatisticsDayService.deleteTAlarmstatisticsDayByIds(ids));
    }

    /**
     * 批量导入报警统计（昨天）
     */
    @PreAuthorize("@ss.hasPermi('production:day:add')")
    @Log(title = "报警统计（昨天）", businessType = BusinessType.INSERT)
    @PostMapping("/importData")
    public AjaxResult importData(@RequestParam("file") MultipartFile file) throws IOException
    {
        //获取操作人员ID
        Long userId = getUserId();
        //报错行数统计
        List<Integer> failRow =new ArrayList<Integer>();
        Workbook workbook = ExcelUtils.getWorkBook(file);
        Sheet sheet = workbook.getSheetAt(0);
        List<TAlarmstatisticsDay> list = new ArrayList<TAlarmstatisticsDay>();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        //字典查询
        List<SysDictData> plant = iSysDictTypeService.selectDictDataByType("PLANT_DIVIDE");
        //部门查询
        List<SysDept> dept = iSysDeptService.selectDeptList(new SysDept());
        int rowNum = sheet.getPhysicalNumberOfRows();
        int failNumber = 0;
        for (int i = 1; i < rowNum; i++) {
            try {
                logger.info("读取行数：" + i);
                Row row = sheet.getRow(i);
                int cellNum = row.getLastCellNum();
                TAlarmstatisticsDay entity = new TAlarmstatisticsDay();
                for (int j = 0; j < cellNum; j++) {
                    Cell cell = row.getCell(j);
                    //  cell.setCellType(CellType.STRING);
                    String cellValue = ExcelUtils.getCellValue(cell);
                    logger.info("cellValue:" + cellValue);
                    if (j == 0) {
                        for (SysDictData p : plant) {
                            if (p.getDictLabel().equals(cellValue.trim())) {
                                entity.setPlantCode(p.getDictValue());//装置名称
                            }
                        }
                    } else if (j == 1) {
                        entity.setModulename(cellValue);//内容
                    } else if (j == 2) {
                        entity.setLevelname(cellValue);//等级
                    } else if (j == 3) {
                        if (cellValue != ""){
                            entity.setCount(Long.parseLong(cellValue));//次数
                        }
                    } else if (j == 4) {
                        if (cellValue.length() > 3) {
                            entity.setInputdate(new SimpleDateFormat(DateUtils.getDateFormat(cellValue)).parse(cellValue));//录入时间
                        }
                    } else if (j == 5) {
                        entity.setRemarks(cellValue);//备注
                    } else if (j == 6) {
                        for (SysDept d : dept) {
                            if (d.getDeptName().equals(cellValue.trim())) {
                                entity.setDeptId(d.getDeptId());//部门编号
                            }
                        }
                    }
                }
                entity.setCreaterCode(userId.toString());
                logger.info("entity:" + entity);
                list.add(entity);
            }catch (Exception e){
                failNumber++;
                failRow.add(i+1);
            }
        }
        int successNumber = 0;
        int failNum = 0;
        for (TAlarmstatisticsDay t : list
        ) {
            failNum++;
            try {
                tAlarmstatisticsDayService.insertTAlarmstatisticsDay(t);
                successNumber++;
            }catch (Exception e){
                failNumber++;
                failRow.add(failNum+1);
            }
        }
        logger.info("list:" + JSON.toJSONString(list));
        logger.info("successNumber:" +String.valueOf(successNumber));
        logger.info("failNumber:" +String.valueOf(failNumber));
        logger.info("failRow:" +String.valueOf(failRow));
        return AjaxResult.success(String.valueOf(successNumber), failRow);
    }
}
